summaryrefslogtreecommitdiffstats
path: root/usr
diff options
context:
space:
mode:
authorgnhb <gnoahb@gmail.com>2010-05-04 15:35:29 +0700
committergnhb <gnoahb@gmail.com>2010-05-04 15:35:29 +0700
commit42809b4a0394bf4f06e7a74bd5f7612e2513d0a4 (patch)
tree4c9974bb9577266888eed951d5f09626542878de /usr
parentde77ffdb1e62343a9483c7ab2cdf594ad6dc482d (diff)
downloadpfsense-42809b4a0394bf4f06e7a74bd5f7612e2513d0a4.zip
pfsense-42809b4a0394bf4f06e7a74bd5f7612e2513d0a4.tar.gz
Use "PPPs" as the new Tab name in Interfaces -> Assign. Rename files and update affected files.
Also, add upgrade_config function 062_to_063.
Diffstat (limited to 'usr')
-rwxr-xr-xusr/local/www/interfaces_assign.php39
-rw-r--r--usr/local/www/interfaces_bridge.php3
-rw-r--r--usr/local/www/interfaces_gif.php3
-rw-r--r--usr/local/www/interfaces_gre.php3
-rwxr-xr-xusr/local/www/interfaces_groups.php3
-rw-r--r--usr/local/www/interfaces_lagg.php3
-rw-r--r--usr/local/www/interfaces_ppps.php (renamed from usr/local/www/interfaces_mlppp.php)50
-rw-r--r--usr/local/www/interfaces_ppps_edit.php (renamed from usr/local/www/interfaces_mlppp_edit.php)69
-rwxr-xr-xusr/local/www/interfaces_qinq.php3
-rwxr-xr-xusr/local/www/interfaces_vlan.php3
-rw-r--r--usr/local/www/interfaces_wireless.php3
-rw-r--r--usr/local/www/javascript/interfaces_ppps_edit/ppps_edit.js (renamed from usr/local/www/javascript/interfaces_mlppp_edit/interfaces_mlppp_edit.js)0
12 files changed, 92 insertions, 90 deletions
diff --git a/usr/local/www/interfaces_assign.php b/usr/local/www/interfaces_assign.php
index ed80d46..d4001d0 100755
--- a/usr/local/www/interfaces_assign.php
+++ b/usr/local/www/interfaces_assign.php
@@ -131,8 +131,10 @@ if (is_array($config['ppps']['ppp']) && count($config['ppps']['ppp'])) {
$portname = $ppp['type'].$pppid;
$portlist[$portname] = $ppp;
$portlist[$portname]['isppp'] = true;
- $portlist[$portname]['pppid'] = $pppid;
- $portlist[$portname]['descr'] = strtoupper($ppp['type']) . $pppid ." - ".$ppp['descr'];
+ if (isset($ppp['descr']))
+ $portlist[$portname]['descr'] = strtoupper($ppp['type']) . " - ". $ppp['descr'];
+ else
+ $portlist[$portname]['descr'] = strtoupper($ppp['type']) . " - ". $ppp['ports'];
}
}
@@ -188,13 +190,6 @@ if ($_POST['apply']) {
if (!$input_errors) {
- /* The 'ifname' must be unset for all PPPs before continuing or we can get legacy data
- left in the ppps config sections */
- if (is_array($config['ppps']['ppp']) && count($config['ppps']['ppp'])){
- foreach ($config['ppps']['ppp'] as $pppid => $ppp) {
- unset($config['ppps']['ppp'][$pppid]['ifname']);
- }
- }
/* No errors detected, so update the config */
foreach ($_POST as $ifname => $ifport) {
@@ -213,12 +208,16 @@ if ($_POST['apply']) {
/*For PPP interfaces, write link type to IP address field to signal that IP
addr is dynamic and comes from PPP, PPPoE, or PPTP */
if (isset($portlist[$ifport]['isppp'])){
+ if ($ifname == "wan")
+ $config['interfaces'][$ifname]['if'] = $portlist[$ifport]['type'] ."0";
+ else
+ $config['interfaces'][$ifname]['if'] = $portlist[$ifport]['type'] . substr($ifname,3);
+
$config['interfaces'][$ifname]['ipaddr'] = $portlist[$ifport]['type'];
- foreach ($config['ppps']['ppp'] as $pppid => $ppp) {
- if ($portlist[$ifport]['pppid'] == $pppid)
- $config['ppps']['ppp'][$pppid]['ifname'] = $ifname;
- }
- }
+ $config['interfaces'][$ifname]['ptpid'] = $portlist[$ifport]['ptpid'];
+ } else
+ unset($config['interfaces'][$ifname]['ptpid']);
+
/* check for wireless interfaces, set or clear ['wireless'] */
if (preg_match($g['wireless_regex'], $ifport)) {
if (!is_array($config['interfaces'][$ifname]['wireless']))
@@ -294,13 +293,6 @@ if ($_GET['act'] == "del") {
unset($config['nat']['rule'][$x]['interface']);
}
}
- /* Clean up association with deleted interface in PPPs config section */
- if (is_array($config['ppps']['ppp']) && count($config['ppps']['ppp'])){
- foreach ($config['ppps']['ppp'] as $pppid => $ppp) {
- if ($ppp['ifname'] == $id)
- unset($config['ppps']['ppp'][$pppid]['ifname']);
- }
- }
write_config();
@@ -396,8 +388,7 @@ if(file_exists("/var/run/interface_mismatch_reboot_needed"))
$tab_array[2] = array("Wireless", false, "interfaces_wireless.php");
$tab_array[3] = array("VLANs", false, "interfaces_vlan.php");
$tab_array[4] = array("QinQs", false, "interfaces_qinq.php");
- $tab_array[5] = array("PPP", false, "interfaces_ppp.php");
- $tab_array[6] = array("MLPPP", false, "interfaces_mlppp.php");
+ $tab_array[5] = array("PPPs", false, "interfaces_ppps.php");
$tab_array[7] = array("GRE", false, "interfaces_gre.php");
$tab_array[8] = array("GIF", false, "interfaces_gif.php");
$tab_array[9] = array("Bridges", false, "interfaces_bridge.php");
@@ -427,7 +418,7 @@ if(file_exists("/var/run/interface_mismatch_reboot_needed"))
<?php foreach ($portlist as $portname => $portinfo): ?>
<option value="<?=$portname;?>" <?php
if (isset($portinfo['isppp'])){
- if ($portinfo['ifname'] == $ifname) echo "selected";
+ if ($portinfo['ptpid'] == $iface['ptpid']) echo "selected";
}
else
if ($portname == $iface['if']) echo "selected";
diff --git a/usr/local/www/interfaces_bridge.php b/usr/local/www/interfaces_bridge.php
index e42e5e5..8244d50 100644
--- a/usr/local/www/interfaces_bridge.php
+++ b/usr/local/www/interfaces_bridge.php
@@ -91,8 +91,7 @@ include("head.inc");
$tab_array[2] = array("Wireless", false, "interfaces_wireless.php");
$tab_array[3] = array("VLANs", false, "interfaces_vlan.php");
$tab_array[4] = array("QinQs", false, "interfaces_qinq.php");
- $tab_array[5] = array("PPP", false, "interfaces_ppp.php");
- $tab_array[6] = array("MLPPP", false, "interfaces_mlppp.php");
+ $tab_array[5] = array("PPPs", false, "interfaces_ppps.php");
$tab_array[7] = array("GRE", false, "interfaces_gre.php");
$tab_array[8] = array("GIF", false, "interfaces_gif.php");
$tab_array[9] = array("Bridges", true, "interfaces_bridge.php");
diff --git a/usr/local/www/interfaces_gif.php b/usr/local/www/interfaces_gif.php
index ad33234..f09ef95 100644
--- a/usr/local/www/interfaces_gif.php
+++ b/usr/local/www/interfaces_gif.php
@@ -90,8 +90,7 @@ include("head.inc");
$tab_array[2] = array("Wireless", false, "interfaces_wireless.php");
$tab_array[3] = array("VLANs", false, "interfaces_vlan.php");
$tab_array[4] = array("QinQs", false, "interfaces_qinq.php");
- $tab_array[5] = array("PPP", false, "interfaces_ppp.php");
- $tab_array[6] = array("MLPPP", false, "interfaces_mlppp.php");
+ $tab_array[5] = array("PPPs", false, "interfaces_ppps.php");
$tab_array[7] = array("GRE", false, "interfaces_gre.php");
$tab_array[8] = array("GIF", true, "interfaces_gif.php");
$tab_array[9] = array("Bridges", false, "interfaces_bridge.php");
diff --git a/usr/local/www/interfaces_gre.php b/usr/local/www/interfaces_gre.php
index 8d72127..b92a25f 100644
--- a/usr/local/www/interfaces_gre.php
+++ b/usr/local/www/interfaces_gre.php
@@ -90,8 +90,7 @@ include("head.inc");
$tab_array[2] = array("Wireless", false, "interfaces_wireless.php");
$tab_array[3] = array("VLANs", false, "interfaces_vlan.php");
$tab_array[4] = array("QinQs", false, "interfaces_qinq.php");
- $tab_array[5] = array("PPP", false, "interfaces_ppp.php");
- $tab_array[6] = array("MLPPP", false, "interfaces_mlppp.php");
+ $tab_array[5] = array("PPPs", false, "interfaces_ppps.php");
$tab_array[7] = array("GRE", true, "interfaces_gre.php");
$tab_array[8] = array("GIF", false, "interfaces_gif.php");
$tab_array[9] = array("Bridges", false, "interfaces_bridge.php");
diff --git a/usr/local/www/interfaces_groups.php b/usr/local/www/interfaces_groups.php
index 6560a12..b582eb2 100755
--- a/usr/local/www/interfaces_groups.php
+++ b/usr/local/www/interfaces_groups.php
@@ -76,8 +76,7 @@ include("head.inc");
$tab_array[2] = array("Wireless", false, "interfaces_wireless.php");
$tab_array[3] = array("VLANs", false, "interfaces_vlan.php");
$tab_array[4] = array("QinQs", false, "interfaces_qinq.php");
- $tab_array[5] = array("PPP", false, "interfaces_ppp.php");
- $tab_array[6] = array("MLPPP", false, "interfaces_mlppp.php");
+ $tab_array[5] = array("PPPs", false, "interfaces_ppps.php");
$tab_array[7] = array("GRE", false, "interfaces_gre.php");
$tab_array[8] = array("GIF", false, "interfaces_gif.php");
$tab_array[9] = array("Bridges", false, "interfaces_bridge.php");
diff --git a/usr/local/www/interfaces_lagg.php b/usr/local/www/interfaces_lagg.php
index 0bd1704..19d2aa2 100644
--- a/usr/local/www/interfaces_lagg.php
+++ b/usr/local/www/interfaces_lagg.php
@@ -96,8 +96,7 @@ include("head.inc");
$tab_array[2] = array("Wireless", false, "interfaces_wireless.php");
$tab_array[3] = array("VLANs", false, "interfaces_vlan.php");
$tab_array[4] = array("QinQs", false, "interfaces_qinq.php");
- $tab_array[5] = array("PPP", false, "interfaces_ppp.php");
- $tab_array[6] = array("MLPPP", false, "interfaces_mlppp.php");
+ $tab_array[5] = array("PPPs", false, "interfaces_ppps.php");
$tab_array[7] = array("GRE", false, "interfaces_gre.php");
$tab_array[8] = array("GIF", false, "interfaces_gif.php");
$tab_array[9] = array("Bridges", false, "interfaces_bridge.php");
diff --git a/usr/local/www/interfaces_qinq.php b/usr/local/www/interfaces_qinq.php
index 22ba578..62e4a41 100755
--- a/usr/local/www/interfaces_qinq.php
+++ b/usr/local/www/interfaces_qinq.php
@@ -98,8 +98,7 @@ include("head.inc");
$tab_array[2] = array("Wireless", false, "interfaces_wireless.php");
$tab_array[3] = array("VLANs", false, "interfaces_vlan.php");
$tab_array[4] = array("QinQs", true, "interfaces_qinq.php");
- $tab_array[5] = array("PPP", false, "interfaces_ppp.php");
- $tab_array[6] = array("MLPPP", false, "interfaces_mlppp.php");
+ $tab_array[5] = array("PPPs", false, "interfaces_ppps.php");
$tab_array[7] = array("GRE", false, "interfaces_gre.php");
$tab_array[8] = array("GIF", false, "interfaces_gif.php");
$tab_array[9] = array("Bridges", false, "interfaces_bridge.php");
diff --git a/usr/local/www/interfaces_vlan.php b/usr/local/www/interfaces_vlan.php
index ab901e6..20f41bb 100755
--- a/usr/local/www/interfaces_vlan.php
+++ b/usr/local/www/interfaces_vlan.php
@@ -92,8 +92,7 @@ include("head.inc");
$tab_array[2] = array("Wireless", false, "interfaces_wireless.php");
$tab_array[3] = array("VLANs", true, "interfaces_vlan.php");
$tab_array[4] = array("QinQs", false, "interfaces_qinq.php");
- $tab_array[5] = array("PPP", false, "interfaces_ppp.php");
- $tab_array[6] = array("MLPPP", false, "interfaces_mlppp.php");
+ $tab_array[5] = array("PPPs", false, "interfaces_ppps.php");
$tab_array[7] = array("GRE", false, "interfaces_gre.php");
$tab_array[8] = array("GIF", false, "interfaces_gif.php");
$tab_array[9] = array("Bridges", false, "interfaces_bridge.php");
diff --git a/usr/local/www/interfaces_wireless.php b/usr/local/www/interfaces_wireless.php
index 847dfe0..f639615 100644
--- a/usr/local/www/interfaces_wireless.php
+++ b/usr/local/www/interfaces_wireless.php
@@ -90,8 +90,7 @@ include("head.inc");
$tab_array[2] = array("Wireless", true, "interfaces_wireless.php");
$tab_array[3] = array("VLANs", false, "interfaces_vlan.php");
$tab_array[4] = array("QinQs", false, "interfaces_qinq.php");
- $tab_array[5] = array("PPP", false, "interfaces_ppp.php");
- $tab_array[6] = array("MLPPP", false, "interfaces_mlppp.php");
+ $tab_array[5] = array("PPPs", false, "interfaces_ppps.php");
$tab_array[7] = array("GRE", false, "interfaces_gre.php");
$tab_array[8] = array("GIF", false, "interfaces_gif.php");
$tab_array[9] = array("Bridges", false, "interfaces_bridge.php");
diff --git a/usr/local/www/javascript/interfaces_mlppp_edit/interfaces_mlppp_edit.js b/usr/local/www/javascript/interfaces_ppps_edit/ppps_edit.js
index a63bde0..a63bde0 100644
--- a/usr/local/www/javascript/interfaces_mlppp_edit/interfaces_mlppp_edit.js
+++ b/usr/local/www/javascript/interfaces_ppps_edit/ppps_edit.js
OpenPOWER on IntegriCloud
diff --git a/usr/local/www/interfaces_mlppp.php b/usr/local/www/interfaces_ppps.php
index 551e9ab..fc598b6 100644
--- a/usr/local/www/interfaces_mlppp.php
+++ b/usr/local/www/interfaces_ppps.php
@@ -1,7 +1,7 @@
<?php
/* $Id$ */
/*
- interfaces_mlppp.php
+ interfaces_ppps.php
part of m0n0wall (http://m0n0.ch/wall)
Copyright (C) 2003-2004 Manuel Kasper <mk@neon1.net>.
@@ -34,10 +34,10 @@
*/
##|+PRIV
##|*IDENT=page-interfaces-mlppp
##|*NAME=Interfaces: mlppp page
##|*DESCR=Allow access to the 'Interfaces: mlppp' page.
##|*MATCH=interfaces_mlppp.php*
##|-PRIV
require("guiconfig.inc");
@@ -48,27 +48,28 @@ if (!is_array($config['ppps']['ppp']))
$a_ppps = &$config['ppps']['ppp'] ;
function ppp_inuse($num) {
- global $a_ppps;
-
- if (isset($a_ppps[$num]['ifname']))
- return true;
- else
- return false;
+ global $config, $g, $a_ppps;
+ $iflist = get_configured_interface_list(false, true);
+ foreach ($iflist as $if) {
+ if (isset($config['interfaces'][$if]['ptpid']) && $config['interfaces'][$if]['ptpid'] == $a_ppps[$num]['ptpid'])
+ return true;
+ }
+ return false;
}
if ($_GET['act'] == "del") {
/* check if still in use */
if (ppp_inuse($_GET['id'])) {
- $input_errors[] = "This MLPPP interface cannot be deleted because it is still being used as an interface.";
+ $input_errors[] = "This point-to-point link cannot be deleted because it is still being used as an interface.";
} else {
unset($a_ppps[$_GET['id']]);
write_config();
- header("Location: interfaces_mlppp.php");
+ header("Location: interfaces_ppps.php");
exit;
}
}
-$pgtitle = "Interfaces: MLPPP";
+$pgtitle = "Interfaces: PPPs";
include("head.inc");
?>
@@ -85,12 +86,11 @@ include("head.inc");
$tab_array[2] = array("Wireless", false, "interfaces_wireless.php");
$tab_array[3] = array("VLANs", false, "interfaces_vlan.php");
$tab_array[4] = array("QinQs", false, "interfaces_qinq.php");
- $tab_array[5] = array("PPP", false, "interfaces_ppp.php");
- $tab_array[6] = array("MLPPP", true, "interfaces_mlppp.php");
- $tab_array[7] = array("GRE", false, "interfaces_gre.php");
- $tab_array[8] = array("GIF", false, "interfaces_gif.php");
- $tab_array[9] = array("Bridges", false, "interfaces_bridge.php");
- $tab_array[10] = array("LAGG", false, "interfaces_lagg.php");
+ $tab_array[5] = array("PPPs", false, "interfaces_ppps.php");
+ $tab_array[6] = array("GRE", false, "interfaces_gre.php");
+ $tab_array[7] = array("GIF", false, "interfaces_gif.php");
+ $tab_array[8] = array("Bridges", false, "interfaces_bridge.php");
+ $tab_array[9] = array("LAGG", false, "interfaces_lagg.php");
display_top_tabs($tab_array);
?>
</td></tr>
@@ -105,9 +105,9 @@ include("head.inc");
<td width="10%" class="list"></td>
</tr>
<?php $i = 0; foreach ($a_ppps as $id => $ppp): ?>
- <tr ondblclick="document.location='interfaces_mlppp_edit.php?id=<?=$i;?>'">
+ <tr ondblclick="document.location='interfaces_ppps_edit.php?id=<?=$i;?>'">
<td class="listr">
- <?=htmlspecialchars($ppp['type'].$id);?>
+ <?=htmlspecialchars($ppp['type']);?>
</td>
<td class="listr">
<?=htmlspecialchars($ppp['ports']);?>
@@ -115,13 +115,13 @@ include("head.inc");
<td class="listbg">
<?=htmlspecialchars($ppp['descr']);?>&nbsp;
</td>
- <td valign="middle" nowrap class="list"> <a href="interfaces_mlppp_edit.php?id=<?=$i;?>"><img src="./themes/<?= $g['theme']; ?>/images/icons/icon_e.gif" width="17" height="17" border="0"></a>
- &nbsp;<a href="interfaces_mlppp.php?act=del&id=<?=$i;?>" onclick="return confirm('Do you really want to delete this PPP interface?')"><img src="./themes/<?= $g['theme']; ?>/images/icons/icon_x.gif" width="17" height="17" border="0"></a></td>
+ <td valign="middle" nowrap class="list"> <a href="interfaces_ppps_edit.php?id=<?=$i;?>"><img src="./themes/<?= $g['theme']; ?>/images/icons/icon_e.gif" width="17" height="17" border="0"></a>
+ &nbsp;<a href="interfaces_ppps.php?act=del&id=<?=$i;?>" onclick="return confirm('Do you really want to delete this PPP interface?')"><img src="./themes/<?= $g['theme']; ?>/images/icons/icon_x.gif" width="17" height="17" border="0"></a></td>
</tr>
<?php $i++; endforeach; ?>
<tr>
<td class="list" colspan="3">&nbsp;</td>
- <td class="list"> <a href="interfaces_mlppp_edit.php"><img src="./themes/<?= $g['theme']; ?>/images/icons/icon_plus.gif" width="17" height="17" border="0"></a></td>
+ <td class="list"> <a href="interfaces_ppps_edit.php"><img src="./themes/<?= $g['theme']; ?>/images/icons/icon_plus.gif" width="17" height="17" border="0"></a></td>
</tr>
</table>
</div>
@@ -34,10 +34,10 @@
*/
##|+PRIV
-##|*IDENT=page-interfaces-mlppp
-##|*NAME=Interfaces: mlppp page
-##|*DESCR=Allow access to the 'Interfaces: mlppp' page.
-##|*MATCH=interfaces_mlppp.php*
+##|*IDENT=page-interfaces-ppps
+##|*NAME=Interfaces: ppps page
+##|*DESCR=Allow access to the 'Interfaces: ppps' page.
+##|*MATCH=interfaces_ppps.php*
##|-PRIV
require("guiconfig.inc");
diff --git a/usr/local/www/interfaces_mlppp_edit.php b/usr/local/www/interfaces_ppps_edit.php
index 0653569..416b081 100644
--- a/usr/local/www/interfaces_mlppp_edit.php
+++ b/usr/local/www/interfaces_ppps_edit.php
@@ -1,7 +1,7 @@
<?php
/* $Id$ */
/*
- interfaces_mlppp_edit.php
+ interfaces_ppps_edit.php
part of m0n0wall (http://m0n0.ch/wall)
Copyright (C) 2003-2004 Manuel Kasper <mk@neon1.net>.
@@ -35,10 +35,10 @@
*/
##|+PRIV
##|*IDENT=page-interfaces-mlppp-edit
##|*NAME=Interfaces: MLPPP: Edit page
##|*DESCR=Allow access to the 'Interfaces: MLPPP: Edit' page.
##|*MATCH=interfaces_mlppp_edit.php*
##|-PRIV
require("guiconfig.inc");
@@ -79,10 +79,6 @@ function getMPDResetTimeFromConfig() {
}
}
-function remove_bad_chars($string) {
- return preg_replace('/[^a-z|_|0-9]/i','',$string);
-}
-
$id = $_GET['id'];
if (isset($_POST['id']))
$id = $_POST['id'];
@@ -176,9 +172,6 @@ if ($_POST) {
unset($input_errors);
$pconfig = $_POST;
- /* filter out spaces from descriptions */
- $_POST['descr'] = remove_bad_chars($_POST['descr']);
-
/* okay first of all, cause we are just hiding the PPPoE HTML
* fields releated to PPPoE resets, we are going to unset $_POST
* vars, if the reset feature should not be used. Otherwise the
@@ -224,6 +217,8 @@ if ($_POST) {
$input_errors[] = "Please choose a Link Type.";
break;
}
+ if ($_POST['type'] == "ppp" && count($_POST['interfaces']) > 1)
+ $input_errors[] = "The PPP link type does not support multilink connections (MLPPP). Please select only one Link Interface.";
if (($_POST['provider'] && !is_domain($_POST['provider'])))
$input_errors[] = "The service name contains invalid characters.";
if (($_POST['idletimeout'] != "") && !is_numericint($_POST['idletimeout']))
@@ -265,6 +260,7 @@ if ($_POST) {
if (!$input_errors) {
$ppp = array();
+ $ppp['ptpid'] = $_POST['ptpid'];
$ppp['type'] = $_POST['type'];
$ppp['ports'] = implode(',', $_POST['interfaces']);
$ppp['username'] = $_POST['username'];
@@ -359,23 +355,37 @@ if ($_POST) {
$ppp['mru'] = implode(',', $_POST['mru']);
else
unset($ppp['mru']);
-
-
+
$iflist = get_configured_interface_list();
- /*
+
foreach ($iflist as $if) {
- if ($config['interfaces'][$if]['if'] == basename($a_ppps[$id]['port']))
- $config['interfaces'][$if]['if'] = basename($ppp['port']);
+ if ($config['interfaces'][$if]['ptpid'] == $a_ppps[$id]['ptpid']){
+ $thisif = $if;
+ break;
+ }
}
- */
if (isset($id) && $a_ppps[$id])
$a_ppps[$id] = $ppp;
else
$a_ppps[] = $ppp;
-
+
write_config();
-
- header("Location: interfaces_mlppp.php");
+
+ if (!empty($thisif)){
+ switch ($ppp['type']) {
+ case "pppoe":
+ interface_pppoe_configure($thisif);
+ break;
+ case "pptp":
+ interface_pptp_configure($thisif);
+ break;
+ case "ppp":
+ interface_ppp_configure($thisif);
+ default:
+ break;
+ }
+ }
+ header("Location: interfaces_ppps.php");
exit;
}
} // end if($_POST)
@@ -469,7 +479,7 @@ function handle_pppoe_reset() {
}
$closehead = false;
-$pgtitle = array("Interfaces","MLPPP","Edit");
+$pgtitle = array("Interfaces","PPPs","Edit");
include("head.inc");
$types = array("select" => "Select", "ppp" => "PPP", "pppoe" => "PPPoE", "pptp" => "PPTP"/*, "l2tp" => "L2TP", "tcp" => "TCP", "udp" => "UDP", "ng" => "Netgraph" */ );
@@ -482,10 +492,10 @@ $types = array("select" => "Select", "ppp" => "PPP", "pppoe" => "PPPoE", "pptp"
<body link="#0000CC" vlink="#0000CC" alink="#0000CC" >
<?php include("fbegin.inc"); ?>
<?php if ($input_errors) print_input_errors($input_errors); ?>
- <form action="interfaces_mlppp_edit.php" method="post" name="iform" id="iform">
+ <form action="interfaces_ppps_edit.php" method="post" name="iform" id="iform">
<table id="interfacetable" width="100%" border="0" cellpadding="6" cellspacing="0">
<tr>
- <td colspan="2" valign="top" class="listtopic">MLPPP configuration</td>
+ <td colspan="2" valign="top" class="listtopic">PPPs configuration</td>
</tr>
<tr>
<td valign="middle" class="vncell"><strong>Link Type</strong></td>
@@ -847,13 +857,22 @@ $types = array("select" => "Select", "ppp" => "PPP", "pppoe" => "PPPoE", "pptp"
</tr>
</table
</td>
+ </tr><?php endfor; ?>
+ <tr style="display:none">
+
</tr>
- <?php endfor; ?>
<tr>
<td width="22%" valign="top">&nbsp;</td>
<td width="78%">
<input name="Submit" type="submit" class="formbtn" value="Save">
<input type="button" value="Cancel" onclick="history.back()">
+ <?php
+ if (isset($a_ppps[$id]['ptpid']))
+ $ptpid = $a_ppps[$id]['ptpid'];
+ else
+ $ptpid = uniqid('', true);
+ ?>
+ <input name="ptpid" type="hidden" value="<?=$ptpid;?>">
<?php if (isset($id) && $a_ppps[$id]): ?>
<input name="id" type="hidden" value="<?=$id;?>">
<?php endif; ?>
@@ -35,10 +35,10 @@
*/
##|+PRIV
-##|*IDENT=page-interfaces-mlppp-edit
-##|*NAME=Interfaces: MLPPP: Edit page
-##|*DESCR=Allow access to the 'Interfaces: MLPPP: Edit' page.
-##|*MATCH=interfaces_mlppp_edit.php*
+##|*IDENT=page-interfaces-ppps-edit
+##|*NAME=Interfaces: PPPs: Edit page
+##|*DESCR=Allow access to the 'Interfaces: PPPs: Edit' page.
+##|*MATCH=interfaces_ppps_edit.php*
##|-PRIV
require("guiconfig.inc");